{% extends "wagtailadmin/skeleton.html" %}
{% load compress static wagtailadmin_tags %}

{% block css %}
    {% compress css %}
        <link rel="stylesheet" href="{% static 'wagtailadmin/css/vendor/jquery-ui/jquery-ui-1.10.3.verdant.css' %}" />
        <link rel="stylesheet" href="{% static 'wagtailadmin/css/core.css' %}" type="text/css" />
        <link rel="stylesheet" href="{%  static 'wagtailgmaps/css/admin.css' %}" type="text/css" />
    {% endcompress %}

    {% block extra_css %}{% endblock %}
{% endblock %}

{% block branding_favicon %}
    <link rel="shortcut icon" href="{% static 'wagtailadmin/images/favicon.ico' %}" />
{% endblock %}

{% block js %}
    <script src="https://maps.google.com/maps/api/js"></script>
    {% compress js %}
        <script src="{% static 'wagtailadmin/js/vendor/jquery-1.10.3.js' %}"></script>
        <script src="{% static 'wagtailadmin/js/vendor/jquery-ui-1.10.3.js' %}"></script>
        <script src="{% static 'wagtailadmin/js/vendor/jquery.datetimepicker.js' %}"></script>
        <script src="{% static 'wagtailadmin/js/vendor/jquery.autosize.js' %}"></script>
        <script src="{% static 'wagtailadmin/js/vendor/bootstrap-transition.js' %}"></script>
        <script src="{% static 'wagtailadmin/js/vendor/bootstrap-modal.js' %}"></script>
        <script src="{% static 'wagtailadmin/js/vendor/bootstrap-tab.js' %}"></script>
        <script src="{% static 'wagtailadmin/js/vendor/jquery.dlmenu.js' %}"></script>
        <script src="{% static 'wagtailadmin/js/core.js' %}"></script>
        {% main_nav_js %}
    {% endcompress %}
    
    {% block extra_js %}{% endblock %}
{% endblock %}